==> testdisk_7.1.orig.tar.bz2: testdisk-7.1/src/lang/qphotorec.tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="518"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Lütfen kurtarılan dosyaların kaydedeceği konumu seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Lütfen ham (raw) dosyayı seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Ham (Raw) Dosyalar (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Sys=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Bilinmiyor</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No harddisk found</source>
        <translation>Sabitdisk bulunamadı.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <translation>Sabitdisk bulunamadı.
Programı kullanmak için yönetici haklarına sahip olmalısınız.
Win9x sürümlerinde DOS versiyonu kullanınız.
Vista ve sonraki sürümlerde program simgesinin üstünde  sağ  tıklayın, ve &quot;Yönetici olarak çalıştır&quot;ı seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No harddisk found
You need to be root to use PhotoRec.</source>
        <translation>Sabitdisk bulunamadı.
PhotoRec&apos;i kullanmanız için &quot;root&quot; kullanıcısı olmalısınız.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Disk yok</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="452"/>
        <source>Add a raw disk image...</source>
        <translation>Ham (Raw) disk imajı ekleyin</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="458"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec ücresiz bir yazılımdır ve verilerin kurtarılması  konusunda herhangi bir garanti vermez.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="459"/>
        <source>Please select a media to recover from</source>
        <translation>Lütfen kurtarılmasını istediğiniz ortamı seçin</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>Başarılı bir kurtarma için disk boyutu doğru tesbit edilmelidir.
Eğer aşağıdaki listedeki bir disk yanlış boyutta belirlenmişse disk jumper ayarını ve BIOS&apos;taki görünümünü kontrol edin, işletim sisteminin  ve sürücülerin en son güncellemelerini yapın.
 </translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="469"/>
        <source>Flags</source>
        <translation>İşareti</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="470"/>
        <source>Type</source>
        <translation>Tipi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="471"/>
        <source>File System</source>
        <translation>Dosya Sistemi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Size</source>
        <translation>Boyutu</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Label</source>
        <translation>Etiketi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="488"/>
        <source>File System type</source>
        <translation>Dosya Sistemi türü</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="489"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>ext2/ext3/ext4 dosya sistemleri</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="490"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="494"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Boş alan: Sadece bir disk olarak tanımlanmamış alanı tara</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="495"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Tamamı: Tüm bölümden dosyaları çıkart</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="522"/>
        <source>&amp;Browse</source>
        <translation>&amp;Gözat</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="538"/>
        <source>&amp;Search</source>
        <translation>&amp;Ara</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="542"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Dosya Formatları</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="642"/>
        <source>Destination:</source>
        <translation>Hedef:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="647"/>
        <source>Recovery completed</source>
        <translation>Kurtarma tamamlandı</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="652"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Bruteforce %1 sektör kaldı (test %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="660"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Tamamlanan %1 - Okunan sektör %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="665"/>
        <source>%1/10 headers found</source>
        <translation>%1/10 kafa bulundu</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="667"/>
        <source>%1 files found</source>
        <translation>%1 dosya bulundu</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="540"/>
        <location filename="src/qphotorec.cpp" line="762"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="750"/>
        <source>File family</source>
        <translation>Dosya ailesi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="751"/>
        <source>Number of files recovered</source>
        <translation>Kurtarılan dosya sayısı</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="834"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Dosya oluşturulamadı</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="835"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Dosya oluşturulamadı! Lütfen başka bir konum seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="854"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>QPhotoRec: Yeterli alan yok!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="855"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Diskte yeterli alan kalmadı!  Lütfen diskte boş alan açın ve/veya başka bir hedef disk seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="924"/>
        <source>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <translation>QPhotoRec özgür bir yazılımdır: Özgür Yazılım Vakfı tarafından yayınlanan GNU Genel Kamu Lisansı (Lisans versiyon 2 ve sonrası) kurallarınca değiştirebilir ve/veya dağıtabilirsiniz.

QPhotoRec  işe yarayacağı öngörüsü ile dağıtılmıştır  fakat; TİCARİ DEĞERİ olduğuna ya da ÖZEL BİR AMACA UYGUN olması konusunda herhangi bir imada bile BULUNMADIĞI gibi verilerinizin kurtarılması konusunda da herhangi bir GARANTİ VERMEZ.  Daha detaylı bilgi için  GNU Genel Kamu Lisansı&apos;nı inceleyin.

QPhotoRec ile birlikte GNU Genel Kamu Lisansı&apos;nın bir kopyasını almış olmalısınız. Eğer yoksa &lt;http://www.gnu.org/licenses/&gt; .</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="925"/>
        <source>QPhotoRec: About</source>
        <translation>QPhotoRec: Hakkında</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="954"/>
        <source>File Formats</source>
        <translation>Dosya Türleri</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>&amp;Reset</source>
        <translation>&amp;Hiçbiri</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="958"/>
        <source>Res&amp;tore</source>
        <translation>&amp;Tümü</translation>
    </message>
</context>
</TS>

==> testdisk_7.2.orig.tar.bz2: testdisk-7.2/src/lang/qphotorec.tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>QPhotorec</name>
    <message>
        <location filename="src/qphotorec.cpp" line="125"/>
        <source>QPhotoRec</source>
        <translation>QPhotoRec</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="156"/>
        <location filename="src/qphotorec.cpp" line="521"/>
        <source>Please select a destination to save the recovered files to.</source>
        <translation>Lütfen kurtarılan dosyaların kaydedeceği konumu seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="170"/>
        <source>Please select a raw file</source>
        <translation>Lütfen ham (raw) dosyayı seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="172"/>
        <source>Raw Files (*.dd *.raw *.img)</source>
        <translation>Ham (Raw) Dosyalar (*.dd *.raw *.img)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="259"/>
        <source>Sys=</source>
        <translation>Sys=</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="261"/>
        <source>Unknown</source>
        <translation>Bilinmiyor</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="377"/>
        <source>No hard disk found</source>
        <oldsource>No harddisk found</oldsource>
        <translation>Sabitdisk bulunamadı.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="379"/>
        <source>No hard disk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</source>
        <oldsource>No harddisk found
You need to be administrator to use this program.
Under Win9x, use the DOS version instead.
Under Vista or later, select this program, right-click and choose &quot;Run as administrator&quot;.</oldsource>
        <translation>Sabitdisk bulunamadı.
Programı kullanmak için yönetici haklarına sahip olmalısınız.
Win9x sürümlerinde DOS versiyonu kullanınız.
Vista ve sonraki sürümlerde program simgesinin üstünde  sağ  tıklayın, ve &quot;Yönetici olarak çalıştır&quot;ı seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="388"/>
        <source>No hard disk found
You need to be root to use PhotoRec.</source>
        <oldsource>No harddisk found
You need to be root to use PhotoRec.</oldsource>
        <translation>Sabitdisk bulunamadı.
PhotoRec&apos;i kullanmanız için &quot;root&quot; kullanıcısı olmalısınız.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="393"/>
        <source>No Disk!</source>
        <translation>Disk yok</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="455"/>
        <source>Add a raw disk image...</source>
        <translation>Ham (Raw) disk imajı ekleyin</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="461"/>
        <source>PhotoRec is free software, and comes with ABSOLUTELY NO WARRANTY.</source>
        <translation>PhotoRec ücresiz bir yazılımdır ve verilerin kurtarılması  konusunda herhangi bir garanti vermez.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="462"/>
        <source>Please select a media to recover from</source>
        <translation>Lütfen kurtarılmasını istediğiniz ortamı seçin</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="465"/>
        <source>Disk capacity must be correctly detected for a successful recovery.
If a disk listed above has an incorrect size, check HD jumper settings and BIOS
detection, and install the latest OS patches and disk drivers.</source>
        <translation>Başarılı bir kurtarma için disk boyutu doğru tesbit edilmelidir.
Eğer aşağıdaki listedeki bir disk yanlış boyutta belirlenmişse disk jumper ayarını ve BIOS&apos;taki görünümünü kontrol edin, işletim sisteminin  ve sürücülerin en son güncellemelerini yapın.
 </translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="472"/>
        <source>Flags</source>
        <translation>İşareti</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="473"/>
        <source>Type</source>
        <translation>Tipi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="474"/>
        <source>File System</source>
        <translation>Dosya Sistemi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="475"/>
        <source>Size</source>
        <translation>Boyutu</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="476"/>
        <source>Label</source>
        <translation>Etiketi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="491"/>
        <source>File System type</source>
        <translation>Dosya Sistemi türü</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="492"/>
        <source>ext2/ext3/ext4 filesystem</source>
        <translation>ext2/ext3/ext4 dosya sistemleri</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="493"/>
        <source>FAT/NTFS/HFS+/ReiserFS/...</source>
        <translation>FAT/NTFS/HFS+/ReiserFS/...</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="497"/>
        <source>Free: Scan for file from unallocated space only</source>
        <translation>Boş alan: Sadece bir disk olarak tanımlanmamış alanı tara</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="498"/>
        <source>Whole: Extract files from whole partition</source>
        <translation>Tamamı: Tüm bölümden dosyaları çıkart</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="525"/>
        <source>&amp;Browse</source>
        <translation>&amp;Gözat</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="541"/>
        <source>&amp;Search</source>
        <translation>&amp;Ara</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="544"/>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="545"/>
        <source>&amp;File Formats</source>
        <translation>&amp;Dosya Formatları</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="645"/>
        <source>Destination:</source>
        <translation>Hedef:</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="650"/>
        <source>Recovery completed</source>
        <translation>Kurtarma tamamlandı</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="655"/>
        <source>Bruteforce %1 sectors remaining (test %2)</source>
        <translation>Bruteforce %1 sektör kaldı (test %2)</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="663"/>
        <source>Pass %1 - Reading sector %2/%3</source>
        <translation>Tamamlanan %1 - Okunan sektör %2/%3</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="668"/>
        <source>%1/10 headers found</source>
        <translation>%1/10 kafa bulundu</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="670"/>
        <source>%1 files found</source>
        <translation>%1 dosya bulundu</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="753"/>
        <source>File family</source>
        <translation>Dosya ailesi</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="543"/>
        <location filename="src/qphotorec.cpp" line="765"/>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="754"/>
        <source>Number of files recovered</source>
        <translation>Kurtarılan dosya sayısı</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="837"/>
        <source>QPhotoRec: Failed to create file!</source>
        <translation>QPhotoRec: Dosya oluşturulamadı</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="838"/>
        <source>Failed to create file! Please choose another destination</source>
        <translation>Dosya oluşturulamadı! Lütfen başka bir konum seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="857"/>
        <source>QPhotoRec: Not enough space!</source>
        <translation>QPhotoRec: Yeterli alan yok!</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="858"/>
        <source>There is not enough space left! Please free disk space and/or choose another destination</source>
        <translation>Diskte yeterli alan kalmadı!  Lütfen diskte boş alan açın ve/veya başka bir hedef disk seçin.</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="927"/>
        <source>QPhotoRec is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</source>
        <oldsource>QPhotoRec is is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

QPhotoRec is is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with QPhotoRec.  If not, see &lt;http://www.gnu.org/licenses/&gt;.</oldsource>
        <translation>QPhotoRec özgür bir yazılımdır: Özgür Yazılım Vakfı tarafından yayınlanan GNU Genel Kamu Lisansı (Lisans versiyon 2 ve sonrası) kurallarınca değiştirebilir ve/veya dağıtabilirsiniz.

QPhotoRec  işe yarayacağı öngörüsü ile dağıtılmıştır  fakat; TİCARİ DEĞERİ olduğuna ya da ÖZEL BİR AMACA UYGUN olması konusunda herhangi bir imada bile BULUNMADIĞI gibi verilerinizin kurtarılması konusunda da herhangi bir GARANTİ VERMEZ.  Daha detaylı bilgi için  GNU Genel Kamu Lisansı&apos;nı inceleyin.

QPhotoRec ile birlikte GNU Genel Kamu Lisansı&apos;nın bir kopyasını almış olmalısınız. Eğer yoksa &lt;http://www.gnu.org/licenses/&gt; .</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="928"/>
        <source>QPhotoRec: About</source>
        <translation>QPhotoRec: Hakkında</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="957"/>
        <source>File Formats</source>
        <translation>Dosya Türleri</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="960"/>
        <source>&amp;Reset</source>
        <translation>&amp;Hiçbiri</translation>
    </message>
    <message>
        <location filename="src/qphotorec.cpp" line="961"/>
        <source>Res&amp;tore</source>
        <translation>&amp;Tümü</translation>
    </message>
</context>
</TS>
